import request from "@/utils/request"

/** 分页列表 */
export function listThreeAssetsProblemReport(query) {
  return request({
    url: "/dataModel/threeAssetsProblemReport/list",
    method: "get",
    params: query
  })
}

/** 详情 */
export function getThreeAssetsProblemReport(id) {
  return request({
    url: "/dataModel/threeAssetsProblemReport/" + id,
    method: "get"
  })
}

/** 新增 */
export function addThreeAssetsProblemReport(data) {
  return request({
    url: "/dataModel/threeAssetsProblemReport",
    method: "post",
    data
  })
}

/** 修改 */
export function updateThreeAssetsProblemReport(data) {
  return request({
    url: "/dataModel/threeAssetsProblemReport",
    method: "put",
    data
  })
}

/** 删除 */
export function delThreeAssetsProblemReport(ids) {
  return request({
    url: "/dataModel/threeAssetsProblemReport/" + ids,
    method: "delete"
  })
}

/** 乡镇下拉 */
export function listThreeAssetsProblemReportTownOptions() {
  return request({
    url: "/dataModel/threeAssetsProblemReport/townOptions",
    method: "get"
  })
}

/** 县→乡镇→村树 */
export function listThreeAssetsProblemReportVillageTree() {
  return request({
    url: "/dataModel/threeAssetsProblemReport/villageTree",
    method: "get"
  })
}
